//
//  VenuesViewController.swift
//  PointrWidgetSample
//
//  Created by Pointr on 05/11/2021.
//

import UIKit
import PointrKit

class VenuesViewController: UITableViewController {

    // To get venue, facility and level data (including external and internal identifiers)
    // you should access the venue facility manager
    var sites = Pointr.shared.siteManager?.sites() ?? []
    
    override func viewDidLoad() {
        super.viewDidLoad()
        title = "Venues"
        
        // Make sure you listen to venues / facilities changes so that
        // you keep your models updated
        Pointr.shared.siteManager?.addListener(self)
    }
}

// MARK: - Table view data source
extension VenuesViewController {
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        return sites.count
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return sites[section].buildings.count
    }

    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "facility-cell", for: indexPath)
        let facility = sites[indexPath.section].buildings[indexPath.row]
        cell.textLabel?.text = facility.title
        return cell
    }

    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let building = sites[indexPath.section].buildings[indexPath.row]
        presentMapWidget(building: building)
    }
    
    override func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return sites[section].title
    }
}

// MARK: - Present MapWidget
extension VenuesViewController {
    
    func presentMapWidget(building: PTRBuilding) {
        // Create a configuration for the map widget.
        // This is the standard one with all components enabled
        let configuration = PTRMapWidgetConfiguration()
        
        // Initialize the map widget with the configuration and set the facility you want to present
        let mapWidget = PTRMapWidgetViewController(configuration: configuration)
        mapWidget.loadAndSet(building: building)

        // Present the map wigdet on screen
        mapWidget.modalPresentationStyle = .fullScreen
        present(mapWidget, animated: true, completion: nil)
    }
}

// MARK: - PTRSiteManagerDelegate
extension VenuesViewController: PTRSiteManagerDelegate {
    
    func onSiteManagerDataChanged() {
        
        // Pointr SDK callbacks might not be triggered on the main thread
        // so make sure you switch thread if you're doing any UI operations.
        OperationQueue.main.addOperation { [weak self] in
            self?.sites = Pointr.shared.siteManager?.sites() ?? []
            self?.tableView.reloadData()
        }
    }
}
